---
title: "NCA CCC"
description: "Terraform compliance scanning for NCA CCC — assess for free, remediate with ComplyForm"
---

import { Badge } from '@astrojs/starlight/components';

<Badge text="Enterprise" variant="danger" />
<Badge text="Government" variant="tip" />

**Issuing body:** [NCA](https://nca.gov.sa)
**Jurisdiction:** Country — Middle East
**Countries:** SA


## Assessment

Assess your infrastructure against NCA CCC for free at any tier:

```bash
complyform assess --frameworks=nca_ccc
```

## Remediation

Requires Enterprise tier ($24,999/yr) for remediation.

```bash
complyform remediate --frameworks=nca_ccc
```

## Related Frameworks

- [NCA ECC](/frameworks/nca_ecc)
- [NCA DCC](/frameworks/nca_dcc)
- [NCA TCC](/frameworks/nca_tcc)
- [NCA CSCC](/frameworks/nca_cscc)
- [NCA OSMACC](/frameworks/nca_osmacc)
- [NCA CGIoT](/frameworks/nca_cgiot)
- [NCA OTCC](/frameworks/nca_otcc)
- [NCA Telework](/frameworks/nca_telework)
- [SAMA CSF](/frameworks/sama_csf)
- [UAE IA](/frameworks/uae_ia)
- [DESC CSP](/frameworks/desc_csp)
- [CBB Cloud](/frameworks/cbb_cloud)
- [CBK CORF Kuwait](/frameworks/cbk_corf)
- [NIA Qatar](/frameworks/nia_qatar)
- [CITRA Kuwait](/frameworks/citra_kuwait)
- [MTCIT Oman](/frameworks/mtcit_oman)
